@@ -27,6 +27,7 @@ pub struct StaticConfigurationBuilder {
     wg_ip: Option<Ipv4Addr>,
     wg_name: Option<String>,
     wg_port: Option<u16>,
+    wg_hopping: Option<bool>,
     admin_port: Option<u16>,
     subnet: Option<ipnet::Ipv4Net>,
     shared_key: Option<Vec<u8>>,
@@ -62,6 +63,10 @@ impl StaticConfigurationBuilder {
         self.wg_port = Some(port);
         self
     }
+    pub fn wg_hopping(mut self, hopping: bool) -> Self {
+        self.wg_hopping = Some(hopping);
+        self
+    }
     pub fn admin_port(mut self, port: u16) -> Self {
         self.admin_port = Some(port);
         self
@@ -103,20 +108,21 @@ impl StaticConfigurationBuilder {
         self
     }
     pub fn build(self) -> StaticConfiguration {
-        let peer_cnt = self.peers.len();
+        let is_static = self.peers.contains_key(self.wg_ip.as_ref().unwrap());
         StaticConfiguration {
             name: self.name.unwrap(),
             ip_list: self.ip_list.unwrap(),
             wg_ip: self.wg_ip.unwrap(),
             wg_name: self.wg_name.unwrap(),
             wg_port: self.wg_port.unwrap(),
+            wg_hopping: self.wg_hopping.unwrap(),
             admin_port: self.admin_port.unwrap(),
             subnet: self.subnet.unwrap(),
             shared_key: self.shared_key.unwrap(),
             my_private_key: self.my_private_key.unwrap(),
             my_public_key: self.my_public_key.unwrap(),
+            is_static,
             peers: self.peers,
-            peer_cnt,
             use_tui: self.use_tui.unwrap(),
             use_existing_interface: self.use_existing_interface.unwrap(),
             network_yaml_filename: self.network_yaml_filename.unwrap(),
@@ -132,13 +138,14 @@ pub struct StaticConfiguration {
     pub wg_ip: Ipv4Addr,
     pub wg_name: String,
     pub wg_port: u16,
+    pub wg_hopping: bool,
     pub admin_port: u16,
     pub subnet: ipnet::Ipv4Net,
     pub shared_key: Vec<u8>,
     pub my_private_key: String,
     pub my_public_key: PublicKeyWithTime,
     pub peers: HashMap<Ipv4Addr, PublicPeer>,
-    pub peer_cnt: usize,
+    pub is_static: bool,
     pub use_tui: bool,
     pub use_existing_interface: bool,
     pub network_yaml_filename: String,
@@ -153,11 +160,14 @@ impl StaticConfiguration {
         let mut lines: Vec<String> = vec![];
         lines.push("[Interface]".to_string());
         lines.push(format!("PrivateKey = {}", self.my_private_key));
-        let port = self
-            .peers
-            .get(&self.wg_ip)
-            .map(|peer| peer.wg_port)
-            .unwrap_or(self.wg_port);
+        let port = if self.wg_hopping {
+            manager.my_local_wg_port
+        } else {
+            self.peers
+                .get(&self.wg_ip)
+                .map(|peer| peer.wg_port)
+                .unwrap_or(self.wg_port)
+        };
         lines.push(format!("ListenPort = {}", port));
 
         for node in manager.all_nodes.values() {
